# Python Elmax Cloud client

Asynchronous Python API client for interacting with the Elmax Cloud services.

This module is not official, developed, supported or endorsed by Elmax.
For questions and other inquiries, use the issue tracker in this repo please.

## Installation

The package is available in the [Python Package Index](https://pypi.python.org/).

```bash
$ pip3 install elmax --user
```

For Nix or NixOS users is a package available. Keep in mind that the lastest
releases might only be present in the `unstable` channel.

```bash
$ nix-env -iA nixos.python38Packages.elmax
```

## Usage

For details about the usage please check the `examples.py` file.

## License

This project is licensed under ASL 2, for more details check LICENSE.
